<?php


namespace FiloBlu\StockaFix\Setup;

use \Magento\Framework\Setup\ModuleContextInterface;
use \Magento\Framework\Setup\SchemaSetupInterface;
use \Magento\Framework\Setup\UpgradeSchemaInterface;

/**
 * Class UpgradeSchema
 * @package FiloBlu\StockaFix\Setup
 */
class UpgradeSchema implements UpgradeSchemaInterface
{

    /**
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function upgrade(
        SchemaSetupInterface $setup,
        ModuleContextInterface $context
    )
    {
        $version = $context->getVersion();

        if (version_compare($version, '1.0.1')  === -1) {
            $this->updateToOneZeroOne($setup, $context);
        }

        if (version_compare($version, '1.0.2') === -1) {
            $this->updateToOneZeroTwo($setup, $context);
        }

        if (version_compare($version, '1.0.3') === -1) {
            $this->updateToOneZeroThree($setup, $context);
        }
    }

    /**
     * Upgrade to version 1.0.1
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function updateToOneZeroOne(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $tableName = $setup->getTable(InstallSchema::REPORTS_TABLE);

        if ($setup->getConnection()->isTableExists(InstallSchema::REPORTS_TABLE) == true) {

            $columns = [
                'menu_show' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_BOOLEAN,
                    'nullable' => false,
                    'comment' => 'Show in menu',
                    'default' => false
                ],
                'menu_label' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Label in menu',
                ],
                'receiver_emails' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Receivers email',
                    'length' => '64k'
                ],
                'schedule_frequency' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Schedule frequency'
                ]
            ];

            $connection = $setup->getConnection();

            foreach ($columns as $name => $definition) {
                $connection->addColumn($tableName, $name, $definition);
            }
        }
    }

    /**
     * Upgrade to version 1.0.2
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function updateToOneZeroTwo(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $tableName = $setup->getTable(InstallSchema::REPORTS_TABLE);

        if ($setup->getConnection()->isTableExists(InstallSchema::REPORTS_TABLE) == true) {

            $columns = [
                'active' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_BOOLEAN,
                    'nullable' => false,
                    'comment' => 'Enable',
                    'default' => false
                ],
                'id_label' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Label id',
                ]

            ];

            $connection = $setup->getConnection();

            foreach ($columns as $name => $definition) {
                $connection->addColumn($tableName, $name, $definition);
            }
        }
    }

    /**
     * Upgrade to version 1.0.3
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function updateToOneZeroThree(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $tableName = $setup->getTable(InstallSchema::REPORTS_TABLE);

        if ($setup->getConnection()->isTableExists(InstallSchema::REPORTS_TABLE) == true) {

            $columns = [
                'driver_settings' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Driver Settings'
                ],
                'driver' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Driver',
                ],
                'schedule_filename' => [
                    'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                    'nullable' => true,
                    'comment' => 'Schedule Filename',
                ]


            ];

            $connection = $setup->getConnection();

            foreach ($columns as $name => $definition) {
                $connection->addColumn($tableName, $name, $definition);
            }
        }
    }
}
